class peg$SyntaxError extends SyntaxError {
	constructor(message, expected, found, location) {
		super(message);
		this.expected = expected;
		this.found = found;
		this.location = location;
		this.name = "SyntaxError";
	}
	format(sources) {
		let str = "Error: " + this.message;
		if (this.location) {
			let src = null;
			const st = sources.find((s) => s.source === this.location.source);
			if (st) {
				src = st.text.split(/\r\n|\n|\r/g);
			}
			const s = this.location.start;
			const offset_s =
				this.location.source &&
				typeof this.location.source.offset === "function"
					? this.location.source.offset(s)
					: s;
			const loc =
				this.location.source + ":" + offset_s.line + ":" + offset_s.column;
			if (src) {
				const e = this.location.end;
				const filler = "".padEnd(offset_s.line.toString().length, " ");
				const line = src[s.line - 1];
				const last = s.line === e.line ? e.column : line.length + 1;
				const hatLen = last - s.column || 1;
				str +=
					"\n --> " +
					loc +
					"\n" +
					filler +
					" |\n" +
					offset_s.line +
					" | " +
					line +
					"\n" +
					filler +
					" | " +
					"".padEnd(s.column - 1, " ") +
					"".padEnd(hatLen, "^");
			} else {
				str += "\n at " + loc;
			}
		}
		return str;
	}
	static buildMessage(expected, found) {
		function hex(ch) {
			return ch.codePointAt(0).toString(16).toUpperCase();
		}
		const nonPrintable = Object.prototype.hasOwnProperty.call(
			RegExp.prototype,
			"unicode",
		)
			? new RegExp("[\\p{C}\\p{Mn}\\p{Mc}]", "gu")
			: null;
		function unicodeEscape(s) {
			if (nonPrintable) {
				return s.replace(nonPrintable, (ch) => "\\u{" + hex(ch) + "}");
			}
			return s;
		}
		function literalEscape(s) {
			return unicodeEscape(
				s
					.replace(/\\/g, "\\\\")
					.replace(/"/g, '\\"')
					.replace(/\0/g, "\\0")
					.replace(/\t/g, "\\t")
					.replace(/\n/g, "\\n")
					.replace(/\r/g, "\\r")
					.replace(/[\x00-\x0F]/g, (ch) => "\\x0" + hex(ch))
					.replace(/[\x10-\x1F\x7F-\x9F]/g, (ch) => "\\x" + hex(ch)),
			);
		}
		function classEscape(s) {
			return unicodeEscape(
				s
					.replace(/\\/g, "\\\\")
					.replace(/\]/g, "\\]")
					.replace(/\^/g, "\\^")
					.replace(/-/g, "\\-")
					.replace(/\0/g, "\\0")
					.replace(/\t/g, "\\t")
					.replace(/\n/g, "\\n")
					.replace(/\r/g, "\\r")
					.replace(/[\x00-\x0F]/g, (ch) => "\\x0" + hex(ch))
					.replace(/[\x10-\x1F\x7F-\x9F]/g, (ch) => "\\x" + hex(ch)),
			);
		}
		const DESCRIBE_EXPECTATION_FNS = {
			literal(expectation) {
				return '"' + literalEscape(expectation.text) + '"';
			},
			class(expectation) {
				const escapedParts = expectation.parts.map((part) =>
					Array.isArray(part)
						? classEscape(part[0]) + "-" + classEscape(part[1])
						: classEscape(part),
				);
				return (
					"[" +
					(expectation.inverted ? "^" : "") +
					escapedParts.join("") +
					"]" +
					(expectation.unicode ? "u" : "")
				);
			},
			any() {
				return "any character";
			},
			end() {
				return "end of input";
			},
			other(expectation) {
				return expectation.description;
			},
		};
		function describeExpectation(expectation) {
			return DESCRIBE_EXPECTATION_FNS[expectation.type](expectation);
		}
		function describeExpected(expected) {
			const descriptions = expected.map(describeExpectation);
			descriptions.sort();
			if (descriptions.length > 0) {
				let j = 1;
				for (let i = 1; i < descriptions.length; i++) {
					if (descriptions[i - 1] !== descriptions[i]) {
						descriptions[j] = descriptions[i];
						j++;
					}
				}
				descriptions.length = j;
			}
			switch (descriptions.length) {
				case 1:
					return descriptions[0];
				case 2:
					return descriptions[0] + " or " + descriptions[1];
				default:
					return (
						descriptions.slice(0, -1).join(", ") +
						", or " +
						descriptions[descriptions.length - 1]
					);
			}
		}
		function describeFound(found) {
			return found ? '"' + literalEscape(found) + '"' : "end of input";
		}
		return (
			"Expected " +
			describeExpected(expected) +
			" but " +
			describeFound(found) +
			" found."
		);
	}
}
function peg$parse(input, options) {
	options = options !== undefined ? options : {};
	const peg$FAILED = {};
	const peg$source = options.grammarSource;
	const peg$startRuleFunctions = {
		properties: peg$parseproperties,
	};
	let peg$startRuleFunction = peg$parseproperties;
	const peg$c0 = "=";
	const peg$c1 = '"';
	const peg$c2 = '\\"';
	const peg$c3 = "true";
	const peg$c4 = "false";
	const peg$c5 = ".";
	const peg$r0 = /^[\t-\n\r =]/;
	const peg$r1 = /^[0-9]/;
	const peg$r2 = /^[ \t\n\r]/;
	const peg$e0 = peg$otherExpectation("name value pair");
	const peg$e1 = peg$literalExpectation("=", false);
	const peg$e2 = peg$otherExpectation("valid value");
	const peg$e3 = peg$otherExpectation("a quoted or unquoted string");
	const peg$e4 = peg$otherExpectation("double quoted string");
	const peg$e5 = peg$literalExpectation('"', false);
	const peg$e6 = peg$literalExpectation('\\"', false);
	const peg$e7 = peg$anyExpectation();
	const peg$e8 = peg$classExpectation(
		[["\t", "\n"], "\r", " ", "="],
		false,
		false,
		false,
	);
	const peg$e9 = peg$otherExpectation("boolean");
	const peg$e10 = peg$literalExpectation("true", false);
	const peg$e11 = peg$literalExpectation("false", false);
	const peg$e12 = peg$otherExpectation("integer");
	const peg$e13 = peg$classExpectation([["0", "9"]], false, false, false);
	const peg$e14 = peg$otherExpectation("number");
	const peg$e15 = peg$literalExpectation(".", false);
	const peg$e16 = peg$classExpectation(
		[" ", "\t", "\n", "\r"],
		false,
		false,
		false,
	);
	function peg$f0(name, value) {
		return { name, value };
	}
	function peg$f1(s) {
		return s.join("");
	}
	function peg$f2(c) {
		return c;
	}
	function peg$f3(s) {
		return text();
	}
	function peg$f4(c) {
		return c;
	}
	function peg$f5(bool) {
		return bool === "true";
	}
	function peg$f6() {
		return parseInt(text(), 10);
	}
	function peg$f7() {
		return parseFloat(text());
	}
	let peg$currPos = options.peg$currPos | 0;
	let peg$savedPos = peg$currPos;
	const peg$posDetailsCache = [{ line: 1, column: 1 }];
	let peg$maxFailPos = peg$currPos;
	let peg$maxFailExpected = options.peg$maxFailExpected || [];
	let peg$silentFails = options.peg$silentFails | 0;
	let peg$result;
	if (options.startRule) {
		if (!(options.startRule in peg$startRuleFunctions)) {
			throw new Error(
				"Can't start parsing from rule \"" + options.startRule + '".',
			);
		}
		peg$startRuleFunction = peg$startRuleFunctions[options.startRule];
	}
	function text() {
		return input.substring(peg$savedPos, peg$currPos);
	}
	function offset() {
		return peg$savedPos;
	}
	function range() {
		return {
			source: peg$source,
			start: peg$savedPos,
			end: peg$currPos,
		};
	}
	function location() {
		return peg$computeLocation(peg$savedPos, peg$currPos);
	}
	function expected(description, location) {
		location =
			location !== undefined
				? location
				: peg$computeLocation(peg$savedPos, peg$currPos);
		throw peg$buildStructuredError(
			[peg$otherExpectation(description)],
			input.substring(peg$savedPos, peg$currPos),
			location,
		);
	}
	function error(message, location) {
		location =
			location !== undefined
				? location
				: peg$computeLocation(peg$savedPos, peg$currPos);
		throw peg$buildSimpleError(message, location);
	}
	function peg$getUnicode(pos = peg$currPos) {
		const cp = input.codePointAt(pos);
		if (cp === undefined) {
			return "";
		}
		return String.fromCodePoint(cp);
	}
	function peg$literalExpectation(text, ignoreCase) {
		return { type: "literal", text, ignoreCase };
	}
	function peg$classExpectation(parts, inverted, ignoreCase, unicode) {
		return { type: "class", parts, inverted, ignoreCase, unicode };
	}
	function peg$anyExpectation() {
		return { type: "any" };
	}
	function peg$endExpectation() {
		return { type: "end" };
	}
	function peg$otherExpectation(description) {
		return { type: "other", description };
	}
	function peg$computePosDetails(pos) {
		let details = peg$posDetailsCache[pos];
		let p;
		if (details) {
			return details;
		} else {
			if (pos >= peg$posDetailsCache.length) {
				p = peg$posDetailsCache.length - 1;
			} else {
				p = pos;
				while (!peg$posDetailsCache[--p]) {}
			}
			details = peg$posDetailsCache[p];
			details = {
				line: details.line,
				column: details.column,
			};
			while (p < pos) {
				if (input.charCodeAt(p) === 10) {
					details.line++;
					details.column = 1;
				} else {
					details.column++;
				}
				p++;
			}
			peg$posDetailsCache[pos] = details;
			return details;
		}
	}
	function peg$computeLocation(startPos, endPos, offset) {
		const startPosDetails = peg$computePosDetails(startPos);
		const endPosDetails = peg$computePosDetails(endPos);
		const res = {
			source: peg$source,
			start: {
				offset: startPos,
				line: startPosDetails.line,
				column: startPosDetails.column,
			},
			end: {
				offset: endPos,
				line: endPosDetails.line,
				column: endPosDetails.column,
			},
		};
		if (offset && peg$source && typeof peg$source.offset === "function") {
			res.start = peg$source.offset(res.start);
			res.end = peg$source.offset(res.end);
		}
		return res;
	}
	function peg$fail(expected) {
		if (peg$currPos < peg$maxFailPos) {
			return;
		}
		if (peg$currPos > peg$maxFailPos) {
			peg$maxFailPos = peg$currPos;
			peg$maxFailExpected = [];
		}
		peg$maxFailExpected.push(expected);
	}
	function peg$buildSimpleError(message, location) {
		return new peg$SyntaxError(message, null, null, location);
	}
	function peg$buildStructuredError(expected, found, location) {
		return new peg$SyntaxError(
			peg$SyntaxError.buildMessage(expected, found),
			expected,
			found,
			location,
		);
	}
	function peg$parseproperties() {
		let s0, s1;
		s0 = [];
		s1 = peg$parsenamevaluepair();
		if (s1 !== peg$FAILED) {
			while (s1 !== peg$FAILED) {
				s0.push(s1);
				s1 = peg$parsenamevaluepair();
			}
		} else {
			s0 = peg$FAILED;
		}
		return s0;
	}
	function peg$parsenamevaluepair() {
		let s0, s1, s2, s3, s4, s5, s6, s7;
		peg$silentFails++;
		s0 = peg$currPos;
		s1 = peg$parse_();
		s2 = peg$parseunquotedstring();
		if (s2 !== peg$FAILED) {
			s3 = peg$parse_();
			if (input.charCodeAt(peg$currPos) === 61) {
				s4 = peg$c0;
				peg$currPos++;
			} else {
				s4 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e1);
				}
			}
			if (s4 !== peg$FAILED) {
				s5 = peg$parse_();
				s6 = peg$parseval();
				if (s6 !== peg$FAILED) {
					s7 = peg$parse_();
					peg$savedPos = s0;
					s0 = peg$f0(s2, s6);
				} else {
					peg$currPos = s0;
					s0 = peg$FAILED;
				}
			} else {
				peg$currPos = s0;
				s0 = peg$FAILED;
			}
		} else {
			peg$currPos = s0;
			s0 = peg$FAILED;
		}
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e0);
			}
		}
		return s0;
	}
	function peg$parseval() {
		let s0, s1;
		peg$silentFails++;
		s0 = peg$parsenumber();
		if (s0 === peg$FAILED) {
			s0 = peg$parseboolean();
			if (s0 === peg$FAILED) {
				s0 = peg$parsestring();
			}
		}
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e2);
			}
		}
		return s0;
	}
	function peg$parsestring() {
		let s0, s1;
		peg$silentFails++;
		s0 = peg$parsequotedstring();
		if (s0 === peg$FAILED) {
			s0 = peg$parseunquotedstring();
		}
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e3);
			}
		}
		return s0;
	}
	function peg$parsequotedstring() {
		let s0, s1, s2, s3;
		peg$silentFails++;
		s0 = peg$currPos;
		if (input.charCodeAt(peg$currPos) === 34) {
			s1 = peg$c1;
			peg$currPos++;
		} else {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e5);
			}
		}
		if (s1 !== peg$FAILED) {
			s2 = peg$parsequotedstringcontent();
			if (s2 !== peg$FAILED) {
				if (input.charCodeAt(peg$currPos) === 34) {
					s3 = peg$c1;
					peg$currPos++;
				} else {
					s3 = peg$FAILED;
					if (peg$silentFails === 0) {
						peg$fail(peg$e5);
					}
				}
				if (s3 !== peg$FAILED) {
					peg$savedPos = s0;
					s0 = peg$f1(s2);
				} else {
					peg$currPos = s0;
					s0 = peg$FAILED;
				}
			} else {
				peg$currPos = s0;
				s0 = peg$FAILED;
			}
		} else {
			peg$currPos = s0;
			s0 = peg$FAILED;
		}
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e4);
			}
		}
		return s0;
	}
	function peg$parsequotedstringcontent() {
		let s0, s1, s2, s3;
		s0 = [];
		s1 = peg$currPos;
		s2 = peg$currPos;
		peg$silentFails++;
		if (input.charCodeAt(peg$currPos) === 34) {
			s3 = peg$c1;
			peg$currPos++;
		} else {
			s3 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e5);
			}
		}
		peg$silentFails--;
		if (s3 === peg$FAILED) {
			s2 = undefined;
		} else {
			peg$currPos = s2;
			s2 = peg$FAILED;
		}
		if (s2 !== peg$FAILED) {
			if (input.substr(peg$currPos, 2) === peg$c2) {
				s3 = peg$c2;
				peg$currPos += 2;
			} else {
				s3 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e6);
				}
			}
			if (s3 === peg$FAILED) {
				if (input.length > peg$currPos) {
					s3 = input.charAt(peg$currPos);
					peg$currPos++;
				} else {
					s3 = peg$FAILED;
					if (peg$silentFails === 0) {
						peg$fail(peg$e7);
					}
				}
			}
			if (s3 !== peg$FAILED) {
				peg$savedPos = s1;
				s1 = peg$f2(s3);
			} else {
				peg$currPos = s1;
				s1 = peg$FAILED;
			}
		} else {
			peg$currPos = s1;
			s1 = peg$FAILED;
		}
		if (s1 !== peg$FAILED) {
			while (s1 !== peg$FAILED) {
				s0.push(s1);
				s1 = peg$currPos;
				s2 = peg$currPos;
				peg$silentFails++;
				if (input.charCodeAt(peg$currPos) === 34) {
					s3 = peg$c1;
					peg$currPos++;
				} else {
					s3 = peg$FAILED;
					if (peg$silentFails === 0) {
						peg$fail(peg$e5);
					}
				}
				peg$silentFails--;
				if (s3 === peg$FAILED) {
					s2 = undefined;
				} else {
					peg$currPos = s2;
					s2 = peg$FAILED;
				}
				if (s2 !== peg$FAILED) {
					if (input.substr(peg$currPos, 2) === peg$c2) {
						s3 = peg$c2;
						peg$currPos += 2;
					} else {
						s3 = peg$FAILED;
						if (peg$silentFails === 0) {
							peg$fail(peg$e6);
						}
					}
					if (s3 === peg$FAILED) {
						if (input.length > peg$currPos) {
							s3 = input.charAt(peg$currPos);
							peg$currPos++;
						} else {
							s3 = peg$FAILED;
							if (peg$silentFails === 0) {
								peg$fail(peg$e7);
							}
						}
					}
					if (s3 !== peg$FAILED) {
						peg$savedPos = s1;
						s1 = peg$f2(s3);
					} else {
						peg$currPos = s1;
						s1 = peg$FAILED;
					}
				} else {
					peg$currPos = s1;
					s1 = peg$FAILED;
				}
			}
		} else {
			s0 = peg$FAILED;
		}
		return s0;
	}
	function peg$parseunquotedstring() {
		let s0, s1;
		s0 = peg$currPos;
		s1 = peg$parseunquotedstringcontent();
		if (s1 !== peg$FAILED) {
			peg$savedPos = s0;
			s1 = peg$f3(s1);
		}
		s0 = s1;
		return s0;
	}
	function peg$parseunquotedstringcontent() {
		let s0, s1, s2, s3;
		s0 = [];
		s1 = peg$currPos;
		s2 = peg$currPos;
		peg$silentFails++;
		s3 = input.charAt(peg$currPos);
		if (peg$r0.test(s3)) {
			peg$currPos++;
		} else {
			s3 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e8);
			}
		}
		peg$silentFails--;
		if (s3 === peg$FAILED) {
			s2 = undefined;
		} else {
			peg$currPos = s2;
			s2 = peg$FAILED;
		}
		if (s2 !== peg$FAILED) {
			if (input.length > peg$currPos) {
				s3 = input.charAt(peg$currPos);
				peg$currPos++;
			} else {
				s3 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e7);
				}
			}
			if (s3 !== peg$FAILED) {
				peg$savedPos = s1;
				s1 = peg$f4(s3);
			} else {
				peg$currPos = s1;
				s1 = peg$FAILED;
			}
		} else {
			peg$currPos = s1;
			s1 = peg$FAILED;
		}
		if (s1 !== peg$FAILED) {
			while (s1 !== peg$FAILED) {
				s0.push(s1);
				s1 = peg$currPos;
				s2 = peg$currPos;
				peg$silentFails++;
				s3 = input.charAt(peg$currPos);
				if (peg$r0.test(s3)) {
					peg$currPos++;
				} else {
					s3 = peg$FAILED;
					if (peg$silentFails === 0) {
						peg$fail(peg$e8);
					}
				}
				peg$silentFails--;
				if (s3 === peg$FAILED) {
					s2 = undefined;
				} else {
					peg$currPos = s2;
					s2 = peg$FAILED;
				}
				if (s2 !== peg$FAILED) {
					if (input.length > peg$currPos) {
						s3 = input.charAt(peg$currPos);
						peg$currPos++;
					} else {
						s3 = peg$FAILED;
						if (peg$silentFails === 0) {
							peg$fail(peg$e7);
						}
					}
					if (s3 !== peg$FAILED) {
						peg$savedPos = s1;
						s1 = peg$f4(s3);
					} else {
						peg$currPos = s1;
						s1 = peg$FAILED;
					}
				} else {
					peg$currPos = s1;
					s1 = peg$FAILED;
				}
			}
		} else {
			s0 = peg$FAILED;
		}
		return s0;
	}
	function peg$parseboolean() {
		let s0, s1;
		peg$silentFails++;
		s0 = peg$currPos;
		if (input.substr(peg$currPos, 4) === peg$c3) {
			s1 = peg$c3;
			peg$currPos += 4;
		} else {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e10);
			}
		}
		if (s1 === peg$FAILED) {
			if (input.substr(peg$currPos, 5) === peg$c4) {
				s1 = peg$c4;
				peg$currPos += 5;
			} else {
				s1 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e11);
				}
			}
		}
		if (s1 !== peg$FAILED) {
			peg$savedPos = s0;
			s1 = peg$f5(s1);
		}
		s0 = s1;
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e9);
			}
		}
		return s0;
	}
	function peg$parseinteger() {
		let s0, s1, s2;
		peg$silentFails++;
		s0 = peg$currPos;
		s1 = [];
		s2 = input.charAt(peg$currPos);
		if (peg$r1.test(s2)) {
			peg$currPos++;
		} else {
			s2 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e13);
			}
		}
		if (s2 !== peg$FAILED) {
			while (s2 !== peg$FAILED) {
				s1.push(s2);
				s2 = input.charAt(peg$currPos);
				if (peg$r1.test(s2)) {
					peg$currPos++;
				} else {
					s2 = peg$FAILED;
					if (peg$silentFails === 0) {
						peg$fail(peg$e13);
					}
				}
			}
		} else {
			s1 = peg$FAILED;
		}
		if (s1 !== peg$FAILED) {
			peg$savedPos = s0;
			s1 = peg$f6();
		}
		s0 = s1;
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e12);
			}
		}
		return s0;
	}
	function peg$parsenumber() {
		let s0, s1, s2, s3, s4;
		peg$silentFails++;
		s0 = peg$currPos;
		s1 = peg$parseinteger();
		if (s1 !== peg$FAILED) {
			s2 = peg$currPos;
			if (input.charCodeAt(peg$currPos) === 46) {
				s3 = peg$c5;
				peg$currPos++;
			} else {
				s3 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e15);
				}
			}
			if (s3 !== peg$FAILED) {
				s4 = peg$parseinteger();
				if (s4 !== peg$FAILED) {
					s3 = [s3, s4];
					s2 = s3;
				} else {
					peg$currPos = s2;
					s2 = peg$FAILED;
				}
			} else {
				peg$currPos = s2;
				s2 = peg$FAILED;
			}
			if (s2 === peg$FAILED) {
				s2 = null;
			}
			peg$savedPos = s0;
			s0 = peg$f7();
		} else {
			peg$currPos = s0;
			s0 = peg$FAILED;
		}
		peg$silentFails--;
		if (s0 === peg$FAILED) {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e14);
			}
		}
		return s0;
	}
	function peg$parse_() {
		let s0, s1;
		peg$silentFails++;
		s0 = [];
		s1 = input.charAt(peg$currPos);
		if (peg$r2.test(s1)) {
			peg$currPos++;
		} else {
			s1 = peg$FAILED;
			if (peg$silentFails === 0) {
				peg$fail(peg$e16);
			}
		}
		while (s1 !== peg$FAILED) {
			s0.push(s1);
			s1 = input.charAt(peg$currPos);
			if (peg$r2.test(s1)) {
				peg$currPos++;
			} else {
				s1 = peg$FAILED;
				if (peg$silentFails === 0) {
					peg$fail(peg$e16);
				}
			}
		}
		peg$silentFails--;
		return s0;
	}
	peg$result = peg$startRuleFunction();
	const peg$success = peg$result !== peg$FAILED && peg$currPos === input.length;
	function peg$throw() {
		if (peg$result !== peg$FAILED && peg$currPos < input.length) {
			peg$fail(peg$endExpectation());
		}
		throw peg$buildStructuredError(
			peg$maxFailExpected,
			peg$maxFailPos < input.length ? peg$getUnicode(peg$maxFailPos) : null,
			peg$maxFailPos < input.length
				? peg$computeLocation(peg$maxFailPos, peg$maxFailPos + 1)
				: peg$computeLocation(peg$maxFailPos, peg$maxFailPos),
		);
	}
	if (options.peg$library) {
		return {
			peg$result,
			peg$currPos,
			peg$FAILED,
			peg$maxFailExpected,
			peg$maxFailPos,
			peg$success,
			peg$throw: peg$success ? undefined : peg$throw,
		};
	}
	if (peg$success) {
		return peg$result;
	} else {
		peg$throw();
	}
}
const peg$allowedStartRules = ["properties"];
export {
	peg$allowedStartRules as StartRules,
	peg$SyntaxError as SyntaxError,
	peg$parse as parse,
};
